@@ -1,9 +1,14 @@
 // Copyright The pipewire-rs Contributors.
 // SPDX-License-Identifier: MIT
 
-use crate::utils::{Fraction, Rectangle};
-use crate::{Error, SpaResult, SpaSuccess};
+use crate::utils::{
+    result::{Error, SpaResult, SpaSuccess},
+    Fraction, Rectangle,
+};
+
+#[cfg(feature = "v0_3_65")]
 use convert_case::{Case, Casing};
+
 use std::{ffi::CStr, fmt::Debug};
 
 #[derive(Copy, Clone, PartialEq, Eq)]
@@ -157,6 +162,7 @@ bitflags::bitflags! {
         /// Each color has been scaled by the alpha value.
         const PREMULTIPLIED_ALPHA = spa_sys::SPA_VIDEO_FLAG_PREMULTIPLIED_ALPHA;
         /// use the format modifier
+        #[cfg(feature = "v0_3_65")]
         const MODIFIER = spa_sys::SPA_VIDEO_FLAG_MODIFIER;
         #[cfg(feature = "v0_3_75")]
         /// format modifier was not fixated yet
@@ -192,6 +198,7 @@ impl VideoInterlaceMode {
     }
 }
 
+#[cfg(feature = "v0_3_65")]
 impl Debug for VideoInterlaceMode {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let c_str = unsafe {
@@ -395,6 +402,11 @@ impl Default for VideoInfoRaw {
 
 impl Debug for VideoInfoRaw {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        #[cfg(feature = "v0_3_65")]
+        let interlace_mode = self.interlace_mode();
+        #[cfg(not(feature = "v0_3_65"))]
+        let interlace_mode = self.interlace_mode().as_raw();
+
         f.debug_struct("VideoInfoRaw")
             .field("format", &self.format())
             .field("flags", &self.flags())
@@ -403,7 +415,7 @@ impl Debug for VideoInfoRaw {
             .field("framerate", &self.framerate())
             .field("max_framerate", &self.max_framerate())
             .field("views", &self.views())
-            .field("interlace_mode", &self.interlace_mode())
+            .field("interlace_mode", &interlace_mode)
             .field("pixel_aspect_ratio", &self.pixel_aspect_ratio())
             .field("multiview_mode", &self.multiview_mode())
             .field("multiview_flags", &self.multiview_flags())
@@ -438,6 +450,7 @@ mod tests {
             "VideoFormat::xRGB_210LE",
             format!("{:?}", VideoFormat::xRGB_210LE)
         );
+        #[cfg(feature = "v0_3_65")]
         assert_eq!(
             "VideoInterlaceMode::Progressive",
             format!("{:?}", VideoInterlaceMode::Progressive)
