@@ -214,7 +214,7 @@ impl<'de, P: FixedSizedPod + CanonicalFixedSizedPod + std::marker::Copy> PodDese
     }
 }
 
-/// This struct is returned by [`PodDeserialize`] implementors on deserialization sucess.
+/// This struct is returned by [`PodDeserialize`] implementors on deserialization success.
 ///
 /// Because this can only be constructed by the [`PodDeserializer`], [`PodDeserialize`] implementors are forced
 /// to finish deserialization of their pod instead of stopping after deserializing only part of a pod.
@@ -563,7 +563,7 @@ impl<'de> PodDeserializer<'de> {
         Ok((elements, success))
     }
 
-    /// Deserialize an `array` pod containing elments of type `T`.
+    /// Deserialize an `array` pod containing elements of type `T`.
     pub fn deserialize_array<V, T>(
         self,
         visitor: V,
@@ -640,7 +640,7 @@ impl<'de> PodDeserializer<'de> {
         where
             E: CanonicalFixedSizedPod + FixedSizedPod + Copy,
         {
-            let flags = ChoiceFlags::from_bits(flags).expect("invalid choice flags");
+            let flags = ChoiceFlags::from_bits_retain(flags);
 
             match choice_type {
                 spa_sys::SPA_CHOICE_None => {
@@ -710,6 +710,11 @@ impl<'de> PodDeserializer<'de> {
         }
 
         match child_type {
+            spa_sys::SPA_TYPE_Bool => {
+                let (values, success) = self.deserialize_choice_values::<bool>(num_values)?;
+                let choice = create_choice(choice_type, values, flags)?;
+                Ok((visitor.visit_choice_bool(choice)?, success))
+            }
             spa_sys::SPA_TYPE_Int => {
                 let (values, success) = self.deserialize_choice_values::<i32>(num_values)?;
                 let choice = create_choice(choice_type, values, flags)?;
@@ -1051,7 +1056,7 @@ impl<'de> ObjectPodDeserializer<'de> {
             let key = deserializer.parse(u32(Endianness::Native))?;
             let flags = deserializer.parse(u32(Endianness::Native))?;
 
-            let flags = PropertyFlags::from_bits_truncate(flags);
+            let flags = PropertyFlags::from_bits_retain(flags);
             let (res, success) = P::deserialize(deserializer)?;
 
             // The amount of bytes deserialized is the length of the remaining input
@@ -1219,6 +1224,14 @@ pub trait Visitor<'de>: Sized {
         Err(DeserializeError::UnsupportedType)
     }
 
+    /// The input contains an [`i32`] choice.
+    fn visit_choice_bool(
+        &self,
+        _choice: Choice<bool>,
+    ) -> Result<Self::Value, DeserializeError<&'de [u8]>> {
+        Err(DeserializeError::UnsupportedType)
+    }
+
     /// The input contains an [`i32`] choice.
     fn visit_choice_i32(
         &self,
@@ -1547,6 +1560,13 @@ impl<'de> Visitor<'de> for ValueVisitor {
         Ok(Value::Object(object))
     }
 
+    fn visit_choice_bool(
+        &self,
+        choice: Choice<bool>,
+    ) -> Result<Self::Value, DeserializeError<&'de [u8]>> {
+        Ok(Value::Choice(ChoiceValue::Bool(choice)))
+    }
+
     fn visit_choice_i32(
         &self,
         choice: Choice<i32>,
@@ -1752,6 +1772,21 @@ impl<'de> Visitor<'de> for ValueArrayFdVisitor {
     }
 }
 
+/// A visitor producing [`Choice`] for boolean choice values.
+pub struct ChoiceBoolVisitor;
+
+impl<'de> Visitor<'de> for ChoiceBoolVisitor {
+    type Value = Choice<bool>;
+    type ArrayElem = Infallible;
+
+    fn visit_choice_bool(
+        &self,
+        choice: Choice<bool>,
+    ) -> Result<Self::Value, DeserializeError<&'de [u8]>> {
+        Ok(choice)
+    }
+}
+
 /// A visitor producing [`Choice`] for integer choice values.
 pub struct ChoiceIntVisitor;
 
